@@ -349,11 +349,35 @@ void mul::do_print_rat_func(const print_context & c, unsigned level,
 		}
 
 	} else {
+		// negative powers are empty
+		if (!latex_tags) {
+			print_overall_coeff(overall_coeff, c, sep, latex_tags);
 
-		print_overall_coeff(overall_coeff, c,
-				latex_tags ? " \\, " : sep, latex_tags);
+			print_exvector(others, c, sep);
+		} else {
+			// Decide which separator to use after the overall
+			// coefficient.
+			// overall coefficient is printed first in the
+			// output, if the first character after the
+			// coefficient is a number, then it is hard to
+			// distinguish these in the latex output:
+			//
+			// sage: e = 2 * 2^(1/3)
+			// sage: print latex(e)
+			// 2 \, 2^{\left(\frac{1}{3}\right)}
+			//
+			// In this case instead of the usual separator \,
+			// we use \cdot
 
-		print_exvector(others, c, sep);
+			std::stringstream tstream;
+			print_latex tcontext(tstream, c.options);
+			print_exvector(others, tcontext, sep);
+			print_overall_coeff(overall_coeff, c,
+					std::isdigit(tstream.peek()) ?
+						" \\cdot " : " \\, ",
+					latex_tags);
+			c.s<<tstream.str();
+		}
 	}
 	if (precedence() <= level){
 		if (latex_tags)
@@ -442,10 +466,6 @@ bool mul::info(unsigned inf) const
 		case info_flags::integer:
 		case info_flags::crational:
 		case info_flags::cinteger:
-		case info_flags::positive:
-		case info_flags::nonnegative:
-		case info_flags::posint:
-		case info_flags::nonnegint:
 		case info_flags::even:
 		case info_flags::crational_polynomial:
 		case info_flags::rational_function: {
@@ -468,39 +488,73 @@ bool mul::info(unsigned inf) const
 			}
 			return false;
 		}
+		case info_flags::positive:
 		case info_flags::negative: {
-			bool neg = false;
+			bool pos = true;
 			epvector::const_iterator i = seq.begin(), end = seq.end();
 			while (i != end) {
 				const ex& factor = recombine_pair_to_ex(*i++);
 				if (factor.info(info_flags::positive))
 					continue;
 				else if (factor.info(info_flags::negative))
-					neg = !neg;
+					pos = !pos;
 				else
 					return false;
 			}
 			if (overall_coeff.info(info_flags::negative))
-				neg = !neg;
-			return neg;
+				pos = !pos;
+			return (inf ==info_flags::positive? pos : !pos);
 		}
+		case info_flags::nonnegative: {
+			bool pos = true;
+			epvector::const_iterator i = seq.begin(), end = seq.end();
+			while (i != end) {
+				const ex& factor = recombine_pair_to_ex(*i++);
+				if (factor.info(info_flags::nonnegative) || factor.info(info_flags::positive))
+					continue;
+				else if (factor.info(info_flags::negative))
+					pos = !pos;
+				else
+					return false;
+			}
+			return (overall_coeff.info(info_flags::negative)? pos : !pos);
+		}
+		case info_flags::posint:
 		case info_flags::negint: {
-			bool neg = false;
+			bool pos = true;
 			epvector::const_iterator i = seq.begin(), end = seq.end();
 			while (i != end) {
 				const ex& factor = recombine_pair_to_ex(*i++);
 				if (factor.info(info_flags::posint))
 					continue;
 				else if (factor.info(info_flags::negint))
-					neg = !neg;
+					pos = !pos;
 				else
 					return false;
 			}
 			if (overall_coeff.info(info_flags::negint))
-				neg = !neg;
+				pos = !pos;
 			else if (!overall_coeff.info(info_flags::posint))
 				return false;
-			return neg;
+			return (inf ==info_flags::posint? pos : !pos); 
+		}
+		case info_flags::nonnegint: {
+			bool pos = true;
+			epvector::const_iterator i = seq.begin(), end = seq.end();
+			while (i != end) {
+				const ex& factor = recombine_pair_to_ex(*i++);
+				if (factor.info(info_flags::nonnegint) || factor.info(info_flags::posint))
+					continue;
+				else if (factor.info(info_flags::negint))
+					pos = !pos;
+				else
+					return false;
+			}
+			if (overall_coeff.info(info_flags::negint))
+				pos = !pos;
+			else if (!overall_coeff.info(info_flags::posint))
+				return false;
+			return pos; 
 		}
 	}
 	return inherited::info(inf);
@@ -510,7 +564,7 @@ bool mul::is_polynomial(const ex & var) const
 {
 	for (epvector::const_iterator i=seq.begin(); i!=seq.end(); ++i) {
 		if (!i->rest.is_polynomial(var) ||
-		    (i->rest.has(var) && !i->coeff.info(info_flags::integer))) {
+		    (i->rest.has(var) && !i->coeff.info(info_flags::nonnegint))) {
 			return false;
 		}
 	}
